/*
 *  Vazaar
 *  file: categories.h
 *
 *
 *  Copyright (C) 2005 Tomás Vírseda <kaskaras@yahoo.es>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _CATEGORIES_H
#define _CATEGORIES_H

#include "vazaar.h"
#include "glade/glade.h"
#include <libgnomevfs/gnome-vfs.h>

typedef struct _VazaarDruidCat VazaarDruidCat;
typedef struct _VazaarCat VazaarCat;
typedef struct _IterCat IterCat;
	
enum {
    DRUIDCAT_PAGE_START,
    DRUIDCAT_PAGE_ONE,
    DRUIDCAT_PAGE_TWO,
    DRUIDCAT_PAGE_FINISH
};

struct _VazaarDruidCat {
    GladeXML		*xml;	/* Glade file */
    GtkWidget		*wparent,	/* Pointer to Main Window */
    				*treecat,	/* TreeView Categories */
    				*dialog,	/* Druid container widget */
    				*name,
    				*desc,
					*iconview,	/* scrolled window for gtk_icon_view */	
    				*iconsel,	/* gtk_icon_view with its own model */
    				*rbParentCat,
    				*treeselcat,	/* TreeView select parent category */
					*frmCats, /* Container frame for checkbox and treeview */
					*btnOK,
					*btnCancel;
    gchar			*editcat;	/* edit_cat != NULL -> edit category */
	GtkTreePath		*icon_path;
    VazaarCat		*new_cat;
};

struct _VazaarCat {
    gchar			*icon;	// Icon
    gboolean         bool;	// ???
    gchar			*name;	// Category name
	gchar			*desc;
    gchar			*root;	// parent category
	gchar			*syst;	// system - you can't erase this category;
};

struct _IterCat {
	gchar 			*name;
	GtkTreeIter		*iter;
};

/*
 * Enum for Categories Treeview
 */
enum {
    CAT_COL_IMG,
    CAT_COL_CHK,
    CAT_COL_NOM,
    CAT_COL_DES,
	CAT_COL_SYS,
    CAT_NUM_COLS
};

/*
 * Types of Categories
 */
enum {
	CAT_TYPE_SYSTEM = 1000,
	CAT_TYPE_SYSTEM_WASTEBASKET = 1001,
	CAT_TYPE_SYSTEM_FAVORITES = 1001,
	CAT_TYPE_SYSTEM_IMPORTANT = 1002,
	CAT_TYPE_SYSTEM_GENERIC = 1003,
	CAT_TYPE_NORMAL = 9000
};

/*
 * XML Functions 
 */

void
vazaar_xml_druidcat_parse_categories(	GtkTreeStore *, 
										GtkTreeIter *,
										xmlNodePtr);
void            
vazaar_xml_cat_add					(	VazaarCat *);

gboolean
vazaar_xml_cat_del					(	const gchar *catname, 
										gboolean force);

VazaarCat
*vazaar_xml_cat_get					(	xmlNodePtr);

VazaarCat
*vazaar_xml_cat_get_parent			(	xmlNodePtr);

void            
vazaar_xml_cat_find					(	xmlNodePtr, 
										gchar *);

gint            
vazaar_xml_cats_savefile			();

void            
vazaar_xml_parse_categories			(	GtkTreeStore *,
					    				GtkTreeIter *,
					    				xmlNodePtr,
										gboolean);

/*
 * GUI Functions 
 */
gboolean
vazaar_gui_foreach_cat_in_item		(	GtkTreeModel	*,
				  						GtkTreePath		*,
				  						GtkTreeIter		*, 
										gchar			*);
										
void            
vazaar_gui_druidCat_delete_event	(	GtkWindow *,
						 				VazaarDruidCat *);
										
void            
vazaar_gui_cat_load					(	Vazaar *);

VazaarCat *     
vazaar_gui_cat_get					(	GtkTreeModel *, GtkTreeIter);

GSList *   
vazaar_gui_cat_selected				(	GtkWidget *);

void
vazaar_gui_cat_add					(	Vazaar *);

void
vazaar_gui_cat_edit					(	Vazaar *);

void            
vazaar_gui_cat_delete				(	Vazaar *);

void            
vazaar_gui_catmodel_refresh			(	GtkTreeView *);

void            
vazaar_gui_catmodel_createview		(	GtkTreeModel *, 
										GtkTreeView *);

void            
vazaar_gui_catmodel_createview_sel	(	GtkTreeModel *, 
										GtkTreeView *);

GtkTreeModel *  
vazaar_gui_catmodel_create_and_fill	();

GtkListStore   *
vazaar_gui_iconmodel_create();

void
vazaar_gui_iconmodel_fill (GtkListStore *);

gchar *
vazaar_gui_iconmodel_get_icon		(GtkWidget *, VazaarDruidCat *);

void
vazaar_gui_iconmodel_set_icon (	VazaarDruidCat *);

GtkTreeModel *  
vazaar_gui_druidcatmodel_create_and_fill	();

gboolean        
vazaar_gui_treecat_foreach_func		(	GtkTreeModel *,
										GtkTreePath *,
										GtkTreeIter *,
										gpointer);


VazaarDruidCat *
vazaar_gui_druidcat_new				(	Vazaar *, 
										VazaarCat *);

void
vazaar_gui_druidcat_connect_signals	(	VazaarDruidCat *);

void
vazaar_gui_druidcat_show			(	VazaarDruidCat *);

void            
vazaar_gui_druidcat_cancel			(	GtkWidget *, 
										VazaarDruidCat *);

void            
vazaar_gui_druidcat_destroy			(	VazaarDruidCat *);

void
vazaar_gui_druidcat_catname_changed	(	GtkWidget *,
						    			VazaarDruidCat *);
										
void
vazaar_gui_druidCat_chkzlc_toggled	(	GtkWidget *,
						   				VazaarDruidCat *);
										
void            
vazaar_gui_druidcat_resume			(	VazaarDruidCat *);

void
vazaar_gui_druidcat_finish			(	GtkWidget *, 
					   					VazaarDruidCat *);

gboolean
vazaar_gui_foreach_selected_cats	(	GtkTreeModel	*,
										GtkTreePath		*,
				   						GtkTreeIter		*, 
										GSList			**);

gboolean
vazaar_gui_foreach_hide_category	(	GtkTreeModel	*,
										GtkTreePath		*,
				   						GtkTreeIter		*, 
										gchar			*);

gboolean
vazaar_gui_foreach_select_parent_category	(	GtkTreeModel	*,
												GtkTreePath		*,
				   								GtkTreeIter		*, 
												gpointer[]);
/*
 * CMD Functions 
 */
gboolean
vazaar_cmd_iconmodel_traverse (	GtkTreeModel * model,
				  				GtkTreePath * path,
				  				GtkTreeIter * iter, 
								VazaarDruidCat	*);


#endif
